@@ -67,23 +67,23 @@
 //!
 //! ## cargo features
 //! - `serde-compat` (default)  
-//! 
+//!
 //!   Enable serde compatibility. See below for more info.  
 //! - `format` (default)  
-//! 
+//!
 //!   When enabled, the generated typescript will be formatted.
 //!   Currently, this sadly adds quite a bit of dependencies.
 //! - `chrono-impl`  
-//! 
+//!
 //!   Implement `TS` for types from chrono  
 //! - `bigdecimal-impl`  
-//! 
+//!
 //!   Implement `TS` for types from bigdecimal  
 //! - `uuid-impl`  
-//! 
+//!
 //!   Implement `TS` for types from uuid  
 //! - `bytes-impl`  
-//! 
+//!
 //!   Implement `TS` for types from bytes  
 //!
 //! If there's a type you're dealing with which doesn't implement `TS`, use `#[ts(type = "..")]` or open a PR.
@@ -121,10 +121,11 @@
 use std::{
     any::TypeId,
     collections::{BTreeMap, BTreeSet, HashMap, HashSet},
+    ops::{Range, RangeInclusive},
+    path::{Path, PathBuf},
 };
 
 pub use ts_rs_macros::TS;
-
 pub use crate::export::ExportError;
 
 #[cfg(feature = "chrono-impl")]
@@ -280,10 +281,11 @@ impl Dependency {
     /// If `T` is not exportable (meaning `T::EXPORT_TO` is `None`), this function will return
     /// `None`
     pub fn from_ty<T: TS>() -> Option<Self> {
+        let exported_to = T::EXPORT_TO?;
         Some(Dependency {
             type_id: TypeId::of::<T>(),
             ts_name: T::name(),
-            exported_to: T::EXPORT_TO?,
+            exported_to,
         })
     }
 }
@@ -303,8 +305,6 @@ macro_rules! impl_primitives {
         }
     )*)* };
 }
-pub(crate) use impl_primitives;
-
 // generate impls for tuples
 macro_rules! impl_tuples {
     ( impl $($i:ident),* ) => {
@@ -449,6 +449,54 @@ impl<K: TS, V: TS> TS for HashMap<K, V> {
     }
 }
 
+impl<I: TS> TS for Range<I> {
+    fn name() -> String {
+        panic!("called Range::name - Did you use a type alias?")
+    }
+
+    fn name_with_type_args(args: Vec<String>) -> String {
+        assert_eq!(
+            args.len(),
+            1,
+            "called Range::name_with_type_args with {} args",
+            args.len()
+        );
+        format!("{{ start: {}, end: {}, }}", &args[0], &args[0])
+    }
+
+    fn dependencies() -> Vec<Dependency> {
+        [Dependency::from_ty::<I>()].into_iter().flatten().collect()
+    }
+
+    fn transparent() -> bool {
+        true
+    }
+}
+
+impl<I: TS> TS for RangeInclusive<I> {
+    fn name() -> String {
+        panic!("called RangeInclusive::name - Did you use a type alias?")
+    }
+
+    fn name_with_type_args(args: Vec<String>) -> String {
+        assert_eq!(
+            args.len(),
+            1,
+            "called RangeInclusive::name_with_type_args with {} args",
+            args.len()
+        );
+        format!("{{ start: {}, end: {}, }}", &args[0], &args[0])
+    }
+
+    fn dependencies() -> Vec<Dependency> {
+        [Dependency::from_ty::<I>()].into_iter().flatten().collect()
+    }
+
+    fn transparent() -> bool {
+        true
+    }
+}
+
 impl_shadow!(as Vec<T>: impl<T: TS> TS for HashSet<T>);
 impl_shadow!(as Vec<T>: impl<T: TS> TS for BTreeSet<T>);
 impl_shadow!(as HashMap<K, V>: impl<K: TS, V: TS> TS for BTreeMap<K, V>);
@@ -481,6 +529,8 @@ impl_primitives! {
     u8, i8, u16, i16, u32, i32, f32, f64, usize, isize => "number",
     u64, i64, u128, i128 => "bigint",
     bool => "boolean",
-    String, &'static str => "string",
+    Path, PathBuf, String, &'static str => "string",
     () => "null"
 }
+#[rustfmt::skip]
+pub(crate) use impl_primitives;
